%define	_bindir	/bin
%define	_libdir /lib
%ifarch x86_64
%define	_libdir /lib64
%endif

%define major		0.5
%define libname		%mklibname brlapi %{major}
%define develname	%mklibname brlapi -d

Name:		brltty
Version:	3.10
Release:	%mkrel 2
License:	GPL+
Group:		System/Servers
URL:		http://mielke.cc/brltty/
Source0:	http://mielke.cc/brltty/releases/%{name}-%{version}.tar.gz
Patch0:		brltty-3.9-varargs.patch
# (fc) 3.7.2-6mdv don't strip executable to have valid debug package (Fedora)
# (aw) re-diffed and re-activated 3.9-4mdv
Patch1:		brltty-3.9-dontstrip.patch
# Works around a build error reported and partially discussed upstream:
# http://www.mail-archive.com/brltty@mielke.cc/msg01377.html
# upstream categorizes this as a workaround not a fix, but no fix seems
# yet to have been made available - AdamW 2008/07
Patch2:		brltty-3.9-buildworkaround.patch
# Slightly hacky fix for Java includes to make it build with openjdk,
# where jni_md.h is in a subdirectory of /include . Should not need to
# patch configure directly - just patching bindings.m4 and running
# autoreconf would be enough - but autoreconf is broken with brltty
# 3.9 - AdamW 2008/07
Patch3:		brltty-3.10-javainclude.patch
BuildRequires:	bison
BuildRequires:	gpm-devel
BuildRequires:	X11-devel
Buildrequires:	python-devel
Buildrequires:  ncurses-devel
Buildrequires:	bluez-devel
Buildrequires:  python-pyrex
Buildrequires:  ocaml
Buildrequires:  festival-devel
Buildrequires:  libbraille-devel
Buildrequires:  speech_tools-devel
Buildrequires:  libalsa-devel
Buildrequires:	java-rpmbuild
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
Summary:	Braille display driver for Linux/Unix

%description
BRLTTY is a background process (daemon) which provides
access to the Linux/Unix console (when in text mode)
for a blind person using a refreshable braille display.
It drives the braille display,
and provides complete screen review functionality.
Some speech capability has also been incorporated.

%package -n %{libname}
Summary:	API for brltty
Group:		System/Libraries
License:	LGPL+
Obsoletes:	%{mklibname brlapi 0.5.1 0} <= %{version}-%{release}
Obsoletes:	%{mklibname brlapi 0.4.1 0} <= %{version}-%{release}

%description -n %{libname}
This package provides the run-time support for the Application
Programming Interface to BRLTTY.

Install this package if you have an application which directly accesses
a refreshable braille display.

%package -n %{develname}
Group:		Development/C
License:	LGPL+
Summary:	Headers, static archive, and documentation for BrlAPI
Provides:	brlapi-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Obsoletes:	%{mklibname brlapi 0.5.1 0 -d} <= %{version}-%{release}
Obsoletes:	%{mklibname brlapi 0.4.1 0 -d} <= %{version}-%{release}

%description -n %{develname}
This package provides the header files, static archive, shared object
linker reference, and reference documentation for BrlAPI (the
Application Programming Interface to BRLTTY).  It enables the
implementation of applications which take direct advantage of a
refreshable braille display in order to present information in ways
which are more appropriate for blind users and/or to provide user
interfaces which are more specifically atuned to their needs.

Install this package if you're developing or maintaining an application
which directly accesses a refreshable braille display.

%package -n brlapi-java
Group:		Development/Java
Summary:	Java bindings for BrlAPI
Requires:	java-devel-openjdk
Obsoletes:	%{mklibname brlapi 0.5}-java <= %{version}-%{release}

%description -n brlapi-java
This package provides the Java bindings for BrlAPI,
which is the Application Programming Interface to BRLTTY.

Install this package if you have a Java application
which directly accesses a refreshable braille display.

%package -n brlapi-python
Summary:	Python bindings for BrlAPI
Group:		Development/Python
Obsoletes:	%{mklibname brlapi 0.5.1 0}-python <= %{version}-%{release}
Obsoletes:	%{mklibname brlapi 0.5}-python <= %{version}-%{release}

%description -n brlapi-python
This package provides the Python bindings for BrlAPI,
which is the Application Programming Interface to BRLTTY.

Install this package if you have a Python application
which directly accesses a refreshable braille display.

%package -n brlapi-ocaml
Summary:	Ocaml bindings for BrlAPI
Group:		Development/Other

%description -n brlapi-ocaml
This package provides the Python bindings for BrlAPI,
which is the Application Programming Interface to BRLTTY.

Install this package if you have a Python application
which directly accesses a refreshable braille display.

%prep
%setup -q
%patch0 -p1 -b .varargs
%patch1 -p1 -b .dontstrip
%patch2 -p1 -b .build
%patch3 -p1 -b .javainclude

%build
# must set this explicitly or else it detects it as /usr and the
# headers aren't found - AdamW 2008/07
export JAVA_HOME=%{java_home}
%configure2_5x --with-install-root="%{buildroot}" --disable-relocatable-install --disable-tcl-bindings
make

%install
rm -rf %{buildroot}
make install install-programs install-tables install-drivers
install -m644 Documents/%{name}.conf -D %{buildroot}%{_sysconfdir}/%{name}.conf
install -m644 Documents/%{name}.1 -D %{buildroot}%{_mandir}/man1/%{name}.1

directory="doc"
mkdir -p "${directory}"
for file in `find . \( -path "./${directory}" -o -path ./Documents \) -prune -o \( -name 'README*' -o -name '*.patch' -o -name '*.txt' -o -name '*
.html' -o -name '*.sgml' -o \( -path "./Bootdisks/*" -type f -perm +ugo=x \) \) -print`
do
   mkdir -p "${directory}/${file%/*}"
   cp -rp "${file}" "${directory}/${file}"
done

%clean
rm -rf %{buildroot}

%if %mdkversion < 200900
%post -n %{libname} -p /sbin/ldconfig
%endif

%if %mdkversion < 200900
%postun -n %{libname} -p /sbin/ldconfig
%endif

%files -n %{name}
%defattr(-,root,root)
%doc README Documents/ChangeLog Documents/TODO
%config(noreplace) %{_sysconfdir}/%{name}.conf
%attr(0755,root,root) %{_bindir}/*
%{_sysconfdir}/%{name}
%{_libdir}/%{name}
%{_mandir}/man1/*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.%{major}*

%files -n %{develname}
%defattr(-,root,root)
%doc Documents/BrlAPIref
%{_libdir}/*.so
%{_libdir}/*.a
%{_includedir}/brlapi.h
%{_includedir}/brlapi_*.h
%{_includedir}/brltty
%{_mandir}/man3/*

%files -n brlapi-java
%defattr(-,root,root)
%{_prefix}/lib/java/libbrlapi_java.so
%{_datadir}/java/brlapi.jar

%files -n brlapi-python
%defattr(-,root,root)
%{py_platsitedir}/brlapi.*
%{py_platsitedir}/Brlapi-*

%files -n brlapi-ocaml
%defattr(-,root,root)
%{_prefix}/%{_lib}/ocaml/brlapi
%{_prefix}/%{_lib}/ocaml/stublibs/dllbrlapi_stubs.so*


%changelog
* Sat Mar 28 2009 Funda Wang <fundawang@mandriva.org> 3.10-2mdv2009.1
+ Revision: 361863
- rebuild for new libxaw

* Fri Dec 26 2008 Adam Williamson <awilliamson@mandriva.org> 3.10-1mdv2009.1
+ Revision: 319142
- guh.
- seriously, what the hell is up with this ocaml crap?
- add package for ocaml bindings
- use proper python macros
- bindings package names should not be libified because they are not shared
  libraries with proper majors: call them brlapi-foo and obsolete the incorrect
  names
- apparently there's no install-help any more
- rebuild with python 2.6
- new release 3.10
- rediff javainclude.patch
- drop declarator.patch (merged upstream)

* Fri Jul 04 2008 Oden Eriksson <oeriksson@mandriva.com> 3.9-7mdv2009.0
+ Revision: 231824
- rebuild

  + Adam Williamson <awilliamson@mandriva.org>
    - better approach to java buildrequires and path suggested by anssi

* Fri Jul 04 2008 Adam Williamson <awilliamson@mandriva.org> 3.9-5mdv2009.0
+ Revision: 231509
- have python package obsolete its old name

* Fri Jul 04 2008 Adam Williamson <awilliamson@mandriva.org> 3.9-4mdv2009.0
+ Revision: 231484
- don't package COPYING
- explicitly specify JAVA_HOME to fix java bindings build
- have actually-useful explicit provides for python and java packages
- enable java bindings build on all arches
- add javainclude.patch to fix java include paths for openjdk
- add declarator.patch to fix "empty declarator" build error (from upstream SVN)
- add buildworkaround.patch to fix a known but yet unresolved build error
  (this workaround provided by upstream in mailing list)
- rediff and reapply varargs.patch and dontstrip.patch (silently disabled by
  aginies in 3.9-1mdv)
- new license policy
- proper library / devel naming policy, not the hideous mess previously used
- slight clean and re-arrange of spec

  + Thierry Vignaud <tvignaud@mandriva.com>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Antoine Ginies <aginies@mandriva.com>
    - remove commented line %%configure due to strange build error on BS...
    - remove redundant install in %%install
    - update buildrequires
    - bump release
    - add some buildrequires, restore java-bindings for 32b

* Mon Mar 10 2008 Antoine Ginies <aginies@mandriva.com> 3.9-1mdv2008.1
+ Revision: 183865
- disable some bindings for the moment
- include new bindings, 3.9 version, major update
- 3.9 version

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix spacing at top of description
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Jun 04 2007 Frederic Crozat <fcrozat@mandriva.com> 3.7.2-6mdv2008.0
+ Revision: 35101
- Patch1 (Fedora): don't strip binaries, otherwise debug packages are empty
- Import brltty



* Sat Aug 12 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.7.2-5
- rebuild for fixed libxaw soname

* Wed Jun 14 2006 Frederic Crozat <fcrozat@mandriva.com> 3.7.2-4mdv2007.0
- generate api library subpackage

* Fri Apr 28 2006 Pixel <pixel@mandriva.com> 3.7.2-3mdk
- rebuild (so that the strange require on libbrlapi.so.0.4 disappear...)

* Tue Mar 28 2006 Pascal Terjan <pterjan@mandriva.org> 3.7.2-2mdk
- BuildRequires X11-devel
- Have /bin/brltty-config executable
- Would need some more fixes (rpath to '../../Programs', use of /lib)

* Fri Mar 24 2006 Per Øyvind Karlsen <pkarlsen@mandriva.com> 3.7.2-1mdk
- 3.7.2
- fix permission on conf file
- regenerate P0
- drop P1 (fixed upstream)
- fix summary-ended-with-dot
- %%mkrel

* Wed Aug 31 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.6-2mdk
- gcc4 fixes

* Mon Nov 15 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.6-1mdk
- 3.6
- regenerate P0

* Tue Sep 14 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 3.5-2mdk
- varargs fixes

* Fri Jun 18 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.5-1mdk
- 3.5 final

* Fri Apr 16 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.5-0.pre3.1mdk
- 3.5pre3

* Fri Apr 02 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.5-0.pre2.1mdk
- 3.5pre2
- enable parallell build again:)

* Thu Jan 22 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.4.1-1mdk
- 3.4.1

* Thu Nov 20 2003 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.3.1-1mdk
- 3.3.1
- disable parallell build, broken:\
- merge with debian patches (P0)

* Sun May 11 2003 Stefan van der Eijk <stefan@eijk.nu> 3.2-0.2mdk
- BuildRequires

* Tue Feb  4 2003 Pixel <pixel@mandrakesoft.com> 3.2-0.1mdk
- new beta
- cleanup

* Sat Feb 01 2003 Lenny Cartier <lenny@mandrakesoft.com 3.1-5mdk
- rebuild

* Mon Nov 04 2002 Lenny Cartier <lenny@mandrakesoft.com> 3.1-4mdk
- from Per Øyvind Karlsen <peroyvind@delonic.no> :
	- Whoopsy! Libraries did'nt go to /lib, fixed

* Wed Oct 30 2002 Per Øyvind Karlsen <peroyvind@delonic.no> 3.1-3mdk
- Added more doc's
- Updated to final(?) 3.1 version

* Wed Oct 30 2002 Per Øyvind Karlsen <peroyvind@delonic.no> 3.1-2mdk
- Added more doc's
- Move stuff into /bin and /lib since we want brltty can be used when only
  the root file system is mounted
- Cleanups

* Wed Oct 30 2002 Per Øyvind Karlsen <peroyvind@delonic.no> 3.1-1mdk
- Initial release
